@@ -376,23 +376,6 @@ class PwpActor:
             # This is probably a transient error due to NFS. Better stop and rerun than keep an inconsistent state
             raise PwpError(f"FAIL:copy '{src}' ->  '{dst}'")
 
-    def backup(self, filename):
-        if not ACTOR.isfile(filename):
-            return
-
-        m1 = re.match(r"(.*)\.bak$", filename)
-        m2 = re.match(r"(.*)\.bak-(\d*)$", filename)
-        if m1:
-            bak = f"{m1.group(1)}.bak-1"
-        elif m2:
-            num = int(m2.group(2))
-            bak = f"{m2.group(1)}.bak-{num + 1}"
-        else:
-            bak = filename + '.bak'
-
-        self.backup(bak)
-        self.copy(filename, bak)
-
     def copytree(self, src, dst):
         """
         copytree(self, src, dst): safely copy src to dst : dst will be a copy of src
@@ -400,7 +383,7 @@ class PwpActor:
         :param dst: destination directory
         :return: None
         """
-        if self.dryrun:
+        if self.dryrun:  # pragma: no cover
             LOGGER.debug(f"Would copytree'{src}' ->  '{dst}'")
             return
 
@@ -415,7 +398,7 @@ class PwpActor:
             raise PwpError(f"FAIL:copytree '{src}' ->  '{dst}'")
 
     def move(self, src, dst, forced=False):
-        if self.dryrun and not forced:
+        if self.dryrun and not forced:  # pragma: no cover
             LOGGER.debug(f"Would move file '{src}' -> '{dst}'")
             return
 
@@ -502,13 +485,9 @@ class PwpActor:
 
     @staticmethod
     def open(filename: str, mode: str):
-        # if self.dryrun:
-        #     LOGGER.debug(f"open '{filename}' ")
-        #     return
-
         if mode == 'r' and not ACTOR.isfile(filename):
             raise PwpError(f"ERROR reading non-existing file {filename}")
-        if "b" in mode:
+        if "b" in mode:  # pragma: no cover
             return open(filename, mode)  # binary mode doesn't take an encoding argument
         return open(filename, mode, encoding="utf-8")
 
@@ -634,7 +613,7 @@ class PwpActor:
             if s in table:
                 new_val += table[s]
                 i += 8
-            elif item[i:i+2] == '\\\\':
+            elif item[i:i+2] == '\\\\':  # pragma: no cover
                 new_val += '\\'
                 i += 2
             else:
@@ -719,7 +698,7 @@ class PwpActor:
     def remote_get(self, remote_file, local_file):
         LOGGER.debug(f"remote get '{remote_file}' -> '{local_file}'")
         # assuming  directory for local exists
-        if self.dryrun:
+        if self.dryrun:  # pragma: no cover
             return
         if self.ssh_connection:
             self.remote_mkdir(self.tmp_dir)
@@ -796,17 +775,17 @@ class PwpActor:
             return False, None, 'No remote parameters', False   # not connecting is not error here
 
         LOGGER.info(f"connect host='{self.remote_host}' port='{self.remote_port}' user='{self.remote_user}'")
-        if self.dryrun:
+        if self.dryrun:  # pragma: no cover
             return False, None, "Dryrun", False  # not connecting is not error here
 
         self.ssh_connection = fabric.Connection(self.remote_host, self.remote_user, self.remote_port)
-        if self.ssh_connection is None:
+        if self.ssh_connection is None:  # pragma: no cover
             LOGGER.info("SSH error while Connecting")
             return False, None, "SSH error Connecting", True
 
         self.ssh_connection.open()
         # by default, self.ssh_connection.open() returns None
-        if not self.ssh_connection.is_connected:
+        if not self.ssh_connection.is_connected:  # pragma: no cover
             LOGGER.info("SSH error while opening the connection")
             return False, None, "SSH error Connecting", True
 
@@ -916,7 +895,7 @@ class PwpActor:
             raise PwpConfigError(f"Error {e} : get id of 1st album '{self.sql_first_album}' ")
 
         for name, sql_id, path, upper, upper_cats, global_rank, rank in cur:
-            if ',' not in upper:
+            if ',' not in upper:  # pragma: no cover
                 # this is really a first level album
                 self.sql_first_album_id = sql_id
                 self.sql_first_album_path = path
@@ -955,7 +934,7 @@ class PwpActor:
         :return: FileInfo or None
         if not found, id is None
         """
-        if not self.sql_connection:
+        if not self.sql_connection:  # pragma: no cover
             return None
 
         LOGGER.debug(f"SQL get information '{filename}'")
@@ -991,7 +970,7 @@ class PwpActor:
 
     def sql_set_data(self, filename, md5, size, width, height, latitude, longitude, author,
                      warn_if_no_change=True):
-        if not self.sql_connection:
+        if not self.sql_connection:  # pragma: no cover
             return False
 
         width = width or 'NULL'
@@ -1213,7 +1192,7 @@ class PwpActor:
         :return: DirInfo
         """
 
-        if not self.sql_connection:
+        if not self.sql_connection:  # pragma: no cover
             return None
         LOGGER.debug(f"SQL insert dir {dir_name} in '{father_info}' at rank {rank} ")
 
@@ -1317,7 +1296,7 @@ class PwpActor:
             return {}                 # pragma: no cover: defensive code
 
         if dir_info is None:
-            return {}
+            return {}                 # pragma: no cover
 
         LOGGER.debug(f"SQL get dir files '{dir_info}'")
 
@@ -1361,7 +1340,7 @@ class PwpActor:
             return {}                 # pragma: no cover: defensive code
 
         if dir_info is None:
-            return {}
+            return {}                 # pragma: no cover
 
         LOGGER.debug(f"SQL get dir sub-dirs '{dir_info}'")
 
@@ -1437,7 +1416,7 @@ class PwpActor:
         """
 
         if not self.sql_connection:
-            return False
+            return False                 # pragma: no cover: defensive code
 
         # first, test that all pictures and subdirectories have been deleted from database
 
@@ -1456,7 +1435,7 @@ class PwpActor:
             raise PwpError(f"SQL Error removing category {dir_info} : still holds files in DB")
 
         sql_sons_descr = ACTOR.sql_get_dir_sub_dirs(dir_info)
-        if sql_sons_descr:
+        if sql_sons_descr:                 # pragma: no cover: defensive code
             for file in sql_sons_descr:
                 LOGGER.msg(f"found subdir {file}")
             raise PwpError(f"SQL Error removing directory {dir_info} : still holds directories in DB")
@@ -1472,7 +1451,7 @@ class PwpActor:
             raise PwpError(f"SQL Error {e} : removing directory {dir_info}")
 
         if cur.affected_rows != 1:
-            nb = cur.affected_rows
+            nb = cur.affected_rows                 # pragma: no cover: defensive code
             raise PwpError(f"SQL Error: {nb} affected rows removing directory {dir_info}")
         return True
 
