@@ -70,14 +70,12 @@ class CVS:
 
 
 class ItemValue:
-    def __init__(self, name: str, state, value: str, helps: str):
+    def __init__(self, name: str, state, value: str, helps: str, i_type):
         self.name = name
         self.state = state
         self.value = value
         self.helps = helps
-
-    def set_value(self, value):
-        self.value = value
+        self.i_type = i_type
 
 
 class ValueSetup:
@@ -164,19 +162,10 @@ class ArgIniItem:
                     helps = setup_val.en_help or self.en_help
                 else:
                     helps = setup_val.fr_help or self.fr_help
-                return ItemValue(self.name, setup_val.state, value, helps)
+                return ItemValue(self.name, setup_val.state, value, helps, self.i_type)
 
         return None
 
-    def write_setup(self, setup, stream, lang='en'):
-        name, status, value, helps = self.get_setup(setup, lang)
-        if name is None:
-            return
-
-        line = f"{self.name} : {value}"
-        le = max(50 - len(line), 0)
-        stream.write(f"{line} {' ' * le}  # {helps}\n\n")
-
     def print_fr(self, full=False):
 
         def fit(val, explain):
@@ -379,21 +368,10 @@ class PwpArgsIni(argparse.ArgumentParser):
             else:
                 res[item.name] = ItemValue(item.name, "",
                                            value=str(item.default),
-                                           helps=item.en_help if lang == 'en' else item.fr_help)
+                                           helps=item.en_help if lang == 'en' else item.fr_help,
+                                           i_type=str)
         return res
 
-    def write_setup(self, setup, filename: str, lang):
-        abs_path = os.path.abspath(filename)
-        LOGGER.debug(f"Build .ini file {abs_path} , lang={lang}")
-        with open(filename, 'w', encoding="utf-8") as f:
-            start = datetime.datetime.now()
-            if lang == 'en':
-                f.write(f"# This file is automatically generated by piwiPre on {start}\n")
-            else:
-                f.write(f"# ATTENTION: Ce fichier est a été généré par piwiPre le {start}\n")
-            for item in self.items_list:
-                item.write_setup(setup, f, lang)
-
     def build_rst(self, filename: str, lang='en'):
         abs_path = os.path.abspath(filename)
         LOGGER.debug(f"Build RST file {abs_path} , lang={lang}")
@@ -431,7 +409,7 @@ class PwpArgsIni(argparse.ArgumentParser):
 
     @staticmethod
     def stringify(value: str):
-        if isinstance(value, str) and '--' in value[1:]:
+        if isinstance(value, str) and '--' in value[1:]:  # pragma: no cover
             LOGGER.warning(f"argument '{value}' contains '--', this is probably an error with 2 flags concatenated")
         if value is True or isinstance(value, str) and value.lower() == 'true':
             return 'true'
@@ -477,6 +455,7 @@ class PwpArgsIni(argparse.ArgumentParser):
             LOGGER.msg(f"chdir '{new_dir}'")
             os.chdir(new_dir)
 
+        exit_after = False
         if '--help' in real_args:
             if language == 'en':
                 self.print_help()
@@ -487,13 +466,16 @@ class PwpArgsIni(argparse.ArgumentParser):
                 return None
             self.print_usage()
             self.print_fr()
-            return None
+            exit_after = True
 
         if '--full-help' in real_args:
             if language == 'en':
                 self.print_usage()
                 return None
             self.print_fr(full=True)
+            exit_after = True
+
+        if exit_after:
             return None
 
         if with_config:
@@ -564,6 +546,10 @@ def args_ini_main(arguments):
                     help='performs the auto-test and exits',
                     action='store_true',
                     location='args')
+    parser.add_item('full-help',
+                    help='prints the help',
+                    action='store_true',
+                    location='args')
 
     # check if actual arguments ask for new configuration items just for test
 
@@ -637,6 +623,9 @@ Management of directories
                         default='false')
     # end of auto-test case
     config = parser.parse_args_and_ini("autotest", "tests.ini", arguments)
+    if config is None:
+        # cmdline arguments say 'exit'
+        return
 
     if config['build-rst-file'] or config['auto-test']:
         parser.build_rst(config['rst-file'] or "../results/test-result.rst")
