@@ -49,7 +49,7 @@ class Field:
 
 
 class PwpDirChooser:
-    def __init__(self, father: 'PwpConfigUI', dir_name):
+    def __init__(self, father: 'PwpConfigUI', dir_name, self_test=False):
         self.dir_name = dir_name
         self.father = father
         self.root = tkinter.Tk()
@@ -84,6 +84,10 @@ class PwpDirChooser:
         row += 1
         self.first_row = row
         self.build_list()
+        if self_test:
+            self.root.after(2 * 1000, lambda: self.enter('..'))
+            self.root.after(3 * 1000, lambda: self.select('..'))
+            self.root.after(4 * 1000, lambda: self.abort())
         self.root.mainloop()
 
     def build_one_line(self, path, row, max_width):
@@ -126,7 +130,7 @@ class PwpDirChooser:
                 row += 1
 
     def abort(self):
-        self.root.destroy()
+        self.root.quit()
 
     def select(self, path: str):
         if path.startswith("[.]"):
@@ -189,7 +193,14 @@ class PwpConfigUI:
 
         # CAVEAT: logo MUST be stored in an attribute, otherwise it is garbage collected !
         self.logo = pwpLogo_png.tk_photo()
-        tkinter.Label(self.frm, image=self.logo).grid(column=0, row=row, sticky="W")
+        try:
+            tkinter.Label(self.frm, image=self.logo).grid(column=0, row=row, sticky="W")
+        except tkinter.TclError:
+            pass
+            # ONLY during coverage test, we try to build 2 times the label
+            # but BytesIO do not support it, and the underlying image has been destroyed
+            # so, the construction fails.
+            # but with normal usage, everything is OK
 
         title_font = tkinter.font.Font(size=14, family="Helvetica", weight="bold")
         lab = ttk.Label(self.frm, font=title_font,
@@ -330,6 +341,12 @@ class PwpConfigUI:
         row += 1
         self.max_common_row = row
         self.reset_to_home()
+        if father.args.test:
+            self.root.after(1 * 1000, lambda: PwpDirChooser(self, os.path.dirname(self.do_file['text']),
+                                                            self_test=True))
+            self.root.after(2 * 1000, self.next)
+            self.root.after(3 * 1000, self.back)
+            self.root.after(5 * 1000, self.exit)
         self.from_python_to_ui()
 
     def separator(self, row, text):
@@ -344,7 +361,7 @@ class PwpConfigUI:
 
     def main_loop(self):
         self.root.mainloop()
-        self.root.destroy()
+        self.root.quit()
 
     def select_dir(self, path):
         self.configurator.set_dir(path)
@@ -477,7 +494,7 @@ class PwpConfigUI:
             self.configurator.set_value(name, field.variable.get())
 
     def exit(self):
-        self.root.destroy()
+        self.root.quit()
 
     def back(self):
         self.stage = 0
@@ -513,6 +530,11 @@ class PwpConfigurator:
                             action='store',
                             choices=['true', 'false'],
                             default="true")
+        parser.add_argument('--test',
+                            help="display the graphical UI for 5 seconds and exist, just for test",
+                            action='store',
+                            choices=['true', 'false'],
+                            default="false")
         parser.add_argument('--chdir',
                             help="change the value of HOME. Still generates the .piwiPre.ini. Mainly used for test",
                             action='store')
@@ -664,7 +686,11 @@ class PwpConfigurator:
 
             pp(f"language :  '{self.language}'")
             for k in self.items:
-                line = f"{k} : '{self.items[k].value}'"
+                uv = self.items[k].value
+                val = (uv if uv in ["", 'true', 'false', 'TRIAGE', 'BACKUP', 'ALBUM', 'WEB', 'fr', 'en']
+                       else int(uv) if self.items[k].i_type == int
+                       else f'{self.items[k].value}')
+                line = f"{k} : {val}"
                 n = max(60 - len(line), 0)
                 helps = self.items[k].helps
                 pp(f"{line} {' ' * n} # {helps}")
