@@ -402,17 +402,17 @@ class PwpData:
             author = config.author(self.model, corr_fr_exif)
             return corr_fr_exif, author
         else:
-            LOGGER.debug("Date = None after correction")
+            LOGGER.debug("Date = None after correction")                              # pragma: no cover: defensive code
 
         if from_filename:
             author = config.author(self.model, from_filename)
             return from_filename, author
 
-        LOGGER.debug(f"No exif nor file dates in '{self.filename}'")
+        LOGGER.debug(f"No exif nor file dates in '{self.filename}'")                  # pragma: no cover: defensive code
 
-        file_date = datetime.datetime.fromtimestamp(os.path.getmtime(self.filename))
-        author = config.author(self.model, file_date)
-        return file_date, author
+        file_date = datetime.datetime.fromtimestamp(os.path.getmtime(self.filename))  # pragma: no cover: defensive code
+        author = config.author(self.model, file_date)                                 # pragma: no cover: defensive code
+        return file_date, author                                                      # pragma: no cover: defensive code
 
     def verify_metadata(self, _stage,
                         config: PwpConfig,
@@ -555,7 +555,7 @@ class PwpImage(PwpData):
             ACTOR.delete(self.filename + '~')
 
     def reopen(self):
-        if self.image is None:
+        if self.image is None:  # pragma: no cover: defensive code
             if not ACTOR.isfile(self.filename):
                 raise PwpInternalError(f"reopen('{self.filename}'")
             self.image = Image.open(self.filename)
@@ -567,7 +567,7 @@ class PwpImage(PwpData):
 
     def save_with_info(self, config: PwpConfig, new_iptc=None):
         if config['dryrun']:
-            LOGGER.debug(f"would save image '{self.filename}'")
+            LOGGER.debug(f"would save image '{self.filename}'")  # pragma: no cover: defensive code
         else:
             # need to create the file BEFORE setting the iptc info
             if self.image is None:
@@ -598,7 +598,7 @@ class PwpImage(PwpData):
         # but DOES NOT TAKE enable-conversion into account.
 
         if stage == "album":
-            if config['dryrun']:
+            if config['dryrun']:  # pragma: no cover: defensive code
                 ACTOR.copy(self.filename, self.backup, forced=True)
             else:
                 ACTOR.move(self.filename, self.backup, forced=True)
@@ -653,7 +653,7 @@ class PwpImage(PwpData):
             pwp_file = PwpFileEntry.lookup(filename, context="web", config=config)
 
             if ACTOR.isfile(self.filename + '~'):
-                ACTOR.delete(self.filename + '~')
+                ACTOR.delete(self.filename + '~')  # pragma: no cover: defensive code
 
             suf = filename[-6:-4]
             if created:
@@ -693,7 +693,7 @@ class PwpImage(PwpData):
             after_creation(created=False)
             return
 
-        if config['dryrun']:
+        if config['dryrun']:  # pragma: no cover: defensive code
             LOGGER.info(f"Would create Thumbnail {width}x{height} crop={crop} name={filename}")
             return
 
@@ -839,7 +839,7 @@ class PwpJpg(PwpImage):
         try:
             return buffer.decode('utf8')
         except UnicodeDecodeError as e:
-            LOGGER.info(f"Error {e} while decoding IPTC {info} for {filename}")
+            LOGGER.info(f"Error {e} while decoding IPTC {info} for {filename}")  # pragma: no cover: defensive code
         return None
 
     def incr_logger_count(self, item=None):
