@@ -218,6 +218,18 @@ class PwpUi:
                        ).grid(column=3, row=row, sticky="W")
 
         self.from_python_to_ui()
+        if installer.args.mode == "test":
+            self.root.after(2 * 1000, self.test_scenario)
+            self.root.after(4 * 1000, lambda: self.root.quit())
+
+    def test_scenario(self):
+        self.do_piwipre.set(1)
+        self.do_mariadb.set(0)
+        self.do_ffmpeg.set(0)
+        self.do_mode.set("test")
+        self.installer.run_min_test(system_dir=False)
+        self.refresh_default_values()
+        self.installer.run()
 
     def separator(self, row, text):
         tkinter.Frame(self.frm, width=900, height=15, ).grid(column=0, row=row, columnspan=8)  # noqa
@@ -231,7 +243,7 @@ class PwpUi:
 
     def main_loop(self):
         self.root.mainloop()
-        self.root.destroy()
+        self.root.quit()
 
     def refresh_default_values(self):
         self.from_ui_to_python()
@@ -277,7 +289,7 @@ class PwpUi:
             self.msg.insert(tkinter.END, line, tag)
 
     def exit(self):
-        self.root.destroy()
+        self.root.quit()
 
     def set_action(self, line1, line2="------ KB/ ------ KB"):
         self.action["text"] = line1
@@ -384,6 +396,7 @@ class Installer:
                               os.path.isfile(f"{self.ffmpeg_path}\\bin\\ffprobe.exe"))
 
         if self.ffmpeg_exists:
+            self.msg("Checking FFMPEG version")
             self.action("Checking FFMPEG version", "ongoing")
             target = f"{self.ffmpeg_path}/bin/ffmpeg.exe"
             try:
@@ -401,6 +414,7 @@ class Installer:
                     self.msg("use --force to force new install")
                     self.args.ffmpeg = False
             self.action("Downloader idle", "------ KB/ ------ KB")
+            self.msg(f"FFMPEG version = {self.ffmpeg_version}")
 
         self.piwipre_path = os.getcwd() if self.args.mode == "test" else (os.environ['PROGRAMFILES(X86)'] + '\\piwiPre')  # noqa
         self.piwipre_exists = False
@@ -468,7 +482,7 @@ class Installer:
             self.ui.add_msg("ERROR  : " + line + '\n', "warning")
         else:
             print(termcolor.colored("ERROR  : " + line, color='red', force_color=True))
-            input("Close window after error?")
+            # input("Close window after error?")
             exit(-1)
 
     def msg(self, line):
@@ -572,14 +586,23 @@ class Installer:
 
     def get_latest_package(self):
         """returns the latest package"""
+        def to_float(des: str):
+            m = re.match(r"(\d+)\.(\d+).?(\d*)", des)
+            if m:
+                a = int(m.group(1))
+                b = int(m.group(2))
+                c = float(m.group(3) or '0.0')
+                return a * 10000 + b + c/10000.0
+            return 0
+
         latest = None
+        latest_float = 0.0
         packages = self.get_json("https://gitlab.com/api/v4/projects/48915444/packages")
         for pack in packages:
-            if latest is None:
+            new_val = to_float(pack['version'])
+            if new_val > latest_float:
                 latest = pack
-            elif pack['version'] > latest['version']:
-                latest = pack
-
+                latest_float = new_val
         return latest
 
     def install_piwipre(self):
@@ -592,7 +615,29 @@ class Installer:
         shutil.copy2(f"{self.piwipre_path}/piwiPre.exe",
                      f"{self.piwipre_path}/piwiPre-{target}.exe")
 
-        self.warning(f"Latest package version '{target}' installed in {self.piwipre_path}")
+        self.download(f"{base}/{target}/pwpConfigurator-{target}.exe",
+                      f"{self.piwipre_path}/pwpConfigurator.exe")
+        shutil.copy2(f"{self.piwipre_path}/pwpConfigurator.exe",
+                     f"{self.piwipre_path}/pwpConfigurator-{target}.exe")
+
+        src = f"{base}/{target}/pwpInstaller-{target}.exe"
+        dst1 = os.path.abspath(f"{self.piwipre_path}/pwpInstaller.exe")
+        dst2 = os.path.abspath(f"{self.piwipre_path}/pwpInstaller-{target}.exe")
+        myself = os.path.abspath(sys.orig_argv[0])
+
+        if myself == dst1:
+            self.download(src, dst2)
+            self.warning(f"Latest package version '{target}' installed as '{dst2}'")
+            self.warning(f"You can copy it: copy  {dst2}  {dst1}")
+        elif myself == dst2:
+            self.download(src, dst1)
+            self.warning(f"Latest package version '{target}' installed as '{dst1}'")
+            self.warning(f"You can copy it: copy  {dst1}  {dst2}")
+        else:
+            self.download(src, dst1)
+            shutil.copy2(dst1, dst2)
+            self.warning(f"Latest package version '{target}' installed as '{dst1}' ")
+            self.warning(f"and also copied as '{dst2}' ")
 
         if not self.args.mode == "test":
             self.add_to_path(os.environ['PROGRAMFILES(X86)'] + '\\piwiPre')  # noqa
@@ -697,7 +742,8 @@ class Installer:
             self.error("INTERNAL ERROR: Not an admin")
 
         try:
-            with winreg.ConnectRegistry(None, winreg.HKEY_USERS) as registry:
+            with winreg.ConnectRegistry(None, winreg.HKEY_USERS) as registry:  # pragma: no cover
+                # requires administrator privileges, which is difficult in automated tests
                 with winreg.OpenKey(registry, self.user_key) as key2:
                     with winreg.CreateKey(key2, "Environment") as key3:  #
                         current = self.get_value(key3, master_key)
@@ -718,9 +764,9 @@ class Installer:
         except Exception as e:
             self.error(f"Exception '{e}' ")
 
-    def run_min_test(self):
+    def run_min_test(self, system_dir=True):
         self.action("Minimal test", "Starting")
-        test_dir = os.environ['PROGRAMFILES(X86)'] + '\\piwiPreTmp'   # noqa
+        test_dir = (os.environ['PROGRAMFILES(X86)'] if system_dir else '.') + '\\piwiPreTmp'   # noqa
         if os.path.isdir(test_dir):
             os.rmdir(test_dir)
             self.msg(f"Removed {test_dir}")
@@ -736,11 +782,11 @@ class Installer:
         if self.args.user:
             self.user_key = self.get_user_key(self.args.user)
         elif self.args.elevation == 'false' and self.args.mode == "test":
-            pass   # this is normal
+            self.msg("No elevation, due to cmdline arguments")
         else:
             self.error("user should have been passed on cmdline")
 
-        if not self.args.piwipre and not self.args.ffmpeg and not self.args.mariadb:
+        if not self.args.piwipre and not self.args.ffmpeg and not self.args.mariadb and self.args.test:
             self.run_min_test()
         if self.args.piwipre:
             self.install_piwipre()
@@ -749,13 +795,13 @@ class Installer:
         if self.args.mariadb:
             self.install_maria_db()
         self.action("Installation", "Done")
-        if self.ui is None and self.args.mode == "install":
-            # if no-elevation,
-            input("Close window?")
+        # if self.ui is None and self.args.mode == "install":
+        #     # if no-elevation,
+        #     input("Close window?")
 
 
 def run_installer(arguments):
-    if platform.system() != "Windows":
+    if platform.system() != "Windows": # pragma: no cover
         print("runs only on windows")
         return
     try:
@@ -764,14 +810,14 @@ def run_installer(arguments):
         print(f"OS Error {e}")
 
 
-def installer_console():
+def installer_console():  # pragma: no cover
     if '--gui' in sys.argv:
         run_installer(sys.argv[1:])
     else:
         run_installer(sys.argv[1:] + ['--gui', 'false'])
 
 
-def installer_gui():
+def installer_gui():   # pragma: no cover
     if '--gui' in sys.argv:
         run_installer(sys.argv[1:])
     else:
