@@ -99,7 +99,7 @@ from piwiPre.pwpLicence import PwpLicence
 # REQ 0233: doc in FRENCH
 # REQ 0234: --enable-pwg-representative
 # REQ 0235: --enable-colors
-# REQ 0236: --reset-ini triage/remote/local/default
+# REQ 0236: --reset-ini triage/remote/local/default ==> pwpConfigurator
 # REQ 0237: --language sets the default value of names and instructions
 # REQ 0238: --auto-install
 # REQ 0239: --piwiPre-path dir
@@ -1095,160 +1095,6 @@ class PwpMain:
         LOGGER.info(f"dump_config({path}): {conf['ini-filename-parsed']}")
         pprint.pprint(conf)
 
-    def reset_ini(self, arg):
-        ini_file = self.parser_config['ini-file']
-        ACTOR.backup(ini_file)
-        if arg == 'triage':
-            with ACTOR.open(ini_file, 'w') as f:
-                f.write("# configuration file automatically generated by piwiPre --reset-ini triage\n")
-                f.write("# Edit to setup your own values\n")
-                f.write("\n")
-                f.write("triage: TRIAGE         # where original pictures are read by piwiPre\n")
-                f.write("album: ALBUM           # where processed pictures are written by piwiPre\n")
-                f.write("backup: BACKUP         # where original pictures are back-up-ed by piwiPre\n")
-                f.write("\n")
-                f.write("web:                   # keep empty: no thumbnails\n")
-                f.write("remote-web:            # keep empty: no remote directory\n")
-                f.write("remote-album:          # keep empty: no remote directory\n")
-                f.write("remote-user:           # keep empty: no remote directory\n")
-                f.write("remote-host:           # keep empty: no remote directory\n")
-                f.write("remote-port:           # keep empty: no remote directory\n")
-                f.write("remote-incoming:       # keep empty: no remote directory\n")
-                f.write("piwigo-user:           # keep empty: no remote directory\n")
-                f.write("sql-user:              # keep empty: no sql database\n")
-                f.write("sql-pwd:               # keep empty: no sql database\n")
-                f.write("sql-host:              # keep empty: no sql database\n")
-                f.write("sql-port:              # keep empty: no sql database\n")
-                f.write("sql-database:          # keep empty: no sql database\n")
-                f.write("\n")
-                f.write("enable-rename: true               # This value is usually OK\n")
-                f.write("enable-rotation: true             # This value is usually OK\n")
-                f.write("enable-metadata: true             # This value is usually OK\n")
-                f.write("enable-conversion: true           # This value is usually OK\n")
-                f.write("trust-date-in-filename: true      # This value is usually OK\n")
-                f.write("\n")
-                f.write("enable-thumbnails: false          # keep false: no thumbnails\n")
-                f.write("enable-remote-web: false          # keep false: no remote directory\n")
-                f.write("enable-remote-album: false        # keep false: no remote directory\n")
-                f.write("enable-database: false            # keep false: no remote directory\n")
-                f.write("enable-auto-configuration: false  # keep false: no remote directory\n")
-                f.write("enable-pwg-representative: false  # keep false: no remote directory\n")
-                f.write("\n")
-                f.write("# End of file\n")
-            LOGGER.msg(f"Generated '{ini_file}' for a local usage\n")
-        elif arg == 'default':
-            self.parser.build_ini_file(ini_file)
-            LOGGER.msg(f"Reset '{ini_file}' to default\n")
-        elif arg == "local":
-            with ACTOR.open(ini_file, 'w') as f:
-                f.write("# configuration file automatically generated by piwiPre --reset-ini local\n")
-                f.write("# Edit to setup your own values\n")
-                f.write("\n")
-                f.write("triage: TRIAGE       # where original pictures are read by piwiPre, you can keep this value\n")
-                f.write("album: ALBUM         # CHANGE THIS to the mount-point of the piwigo album\n")
-                f.write("backup: BACKUP       # where original pictures are copied by piwiPre, you can keep this\n")
-                f.write("web: WEB             # CHANGE THIS to the mount-point of the piwigo thumbnails\n")
-                f.write("\n")
-                f.write("remote-web:          # keep empty: no remote directory\n")
-                f.write("remote-album:        # keep empty: no remote directory\n")
-                f.write("remote-user:         # keep empty: no remote directory\n")
-                f.write("remote-host:         # keep empty: no remote directory\n")
-                f.write("remote-port:         # keep empty: no remote directory\n")
-                f.write("remote-incoming:     # keep empty: no remote directory\n")
-                f.write("\n")
-                f.write("# piwigo-user:         # in HOME/.piwiPre.ini: CHANGE THIS to the name of the piwigo user\n")
-                f.write("# sql-user:            # in HOME/.piwiPre.ini: CHANGE THIS to the name of the sql user\n")
-                f.write("# sql-pwd:             # in HOME/.piwiPre.ini: CHANGE THIS to the pwd of sql user\n")
-                f.write("# sql-host:            # in HOME/.piwiPre.ini: CHANGE THIS to the sql host\n")
-                f.write("# sql-port:            # in HOME/.piwiPre.ini: CHANGE THIS to the sql port\n")
-                f.write("# sql-database:        # in HOME/.piwiPre.ini: CHANGE THIS to the sql database\n")
-                f.write("\n")
-                f.write("enable-rename: true               # This value is usually OK\n")
-                f.write("enable-rotation: true             # This value is usually OK\n")
-                f.write("enable-metadata: true             # This value is usually OK\n")
-                f.write("enable-conversion: true           # This value is usually OK\n")
-                f.write("trust-date-in-filename: true      # This value is usually OK\n")
-                f.write("\n")
-                f.write("enable-thumbnails: true           # keep true\n")
-                f.write("enable-remote-web: false          # keep false: no remote directory\n")
-                f.write("enable-remote-album: false        # keep false: no remote directory\n")
-                f.write("enable-database: true             # keep true\n")
-                f.write("enable-auto-configuration: true   # This value is usually OK\n")
-                f.write("enable-pwg-representative: true   # keep true\n")
-                f.write("\n")
-                f.write("# End of file\n")
-            LOGGER.msg(f"Generated '{ini_file}' for a local usage")
-            LOGGER.msg("")
-            LOGGER.msg(f"your HOME is '{os.path.expanduser('~')}'")
-            LOGGER.msg("")
-            LOGGER.msg("The following value SHOULD be set in HOME/.piwiPre.ini:")
-            LOGGER.msg("   piwigo-user:         # CHANGE THIS to the name of the piwigo user")
-            LOGGER.msg("   sql-user:            # CHANGE THIS to the name of the sql user")
-            LOGGER.msg("   sql-pwd:             # CHANGE THIS to the pwd of sql user")
-            LOGGER.msg("   sql-host:            # CHANGE THIS to the sql host")
-            LOGGER.msg("   sql-port:            # CHANGE THIS to the sql port")
-            LOGGER.msg("   sql-database:        # CHANGE THIS to the sql database")
-            LOGGER.msg("")
-        elif arg == "remote":
-            with ACTOR.open(ini_file, 'w') as f:
-                f.write("# configuration file automatically generated by piwiPre --reset-ini remote\n")
-                f.write("# Edit to setup your own values\n")
-                f.write("\n")
-                f.write("triage: TRIAGE       # where original pictures are read by piwiPre, you can keep this value\n")
-                f.write("album: ALBUM         # temporary directory where processed pictures are written by piwiPre\n")
-                f.write("backup: BACKUP       # where original pictures are copied by piwiPre, you can keep this\n")
-                f.write("web: WEB             # temporary directory where piwigo thumbnails are written\n")
-                f.write("\n")
-                f.write("# remote-web:        # in HOME/.piwiPre.ini: the remote directory for thumbnails\n")
-                f.write("# remote-album:      # in HOME/.piwiPre.ini: the remote directory for albums\n")
-                f.write("# remote-user:       # in HOME/.piwiPre.ini: the ssh user\n")
-                f.write("# remote-host:       # in HOME/.piwiPre.ini: the ssh host\n")
-                f.write("# remote-port:       # in HOME/.piwiPre.ini: the ssh port\n")
-                f.write("# remote-incoming:   # in HOME/.piwiPre.ini: ssh incoming directory\n")
-                f.write("\n")
-                f.write("# piwigo-user:       # in HOME/.piwiPre.ini: CHANGE THIS to the name of the piwigo user\n")
-                f.write("# sql-user:          # in HOME/.piwiPre.ini: CHANGE THIS to the name of the sql user\n")
-                f.write("# sql-pwd:           # in HOME/.piwiPre.ini: CHANGE THIS to the pwd of sql user\n")
-                f.write("# sql-host:          # in HOME/.piwiPre.ini: CHANGE THIS to the sql host\n")
-                f.write("# sql-port:          # in HOME/.piwiPre.ini: CHANGE THIS to the sql port\n")
-                f.write("# sql-database:      # in HOME/.piwiPre.ini: CHANGE THIS to the sql database\n")
-                f.write("\n")
-                f.write("enable-rename: true               # This value is usually OK\n")
-                f.write("enable-rotation: true             # This value is usually OK\n")
-                f.write("enable-metadata: true             # This value is usually OK\n")
-                f.write("enable-conversion: true           # This value is usually OK\n")
-                f.write("trust-date-in-filename: true      # This value is usually OK\n")
-                f.write("\n")
-                f.write("enable-thumbnails: true           # keep true\n")
-                f.write("enable-remote-web: true           # keep true: remote directory\n")
-                f.write("enable-remote-album: true         # keep true: remote directory\n")
-                f.write("enable-database: true             # keep true\n")
-                f.write("enable-auto-configuration: true   # This value is usually OK\n")
-                f.write("enable-pwg-representative: true   # keep true\n")
-                f.write("\n")
-                f.write("# End of file\n")
-            LOGGER.msg(f"Generated '{ini_file}' for a remote usage")
-            LOGGER.msg("")
-            LOGGER.msg(f"your HOME is '{os.path.expanduser('~')}'")
-            LOGGER.msg("")
-            LOGGER.msg("The following value SHOULD be set in HOME/.piwiPre.ini:")
-            LOGGER.msg("   piwigo-user:         # SET the name of the piwigo user")
-            LOGGER.msg("   sql-user:            # SET the name of the sql user")
-            LOGGER.msg("   sql-pwd:             # SET the pwd of sql user")
-            LOGGER.msg("   sql-host:            # SET the sql host")
-            LOGGER.msg("   sql-port:            # SET the sql port")
-            LOGGER.msg("   sql-database:        # SET the sql database")
-            LOGGER.msg("")
-            LOGGER.msg("   remote-web:          # SET the remote directory for thumbnails")
-            LOGGER.msg("   remote-album:        # SET the remote directory for albums")
-            LOGGER.msg("   remote-user:         # SET the ssh user")
-            LOGGER.msg("   remote-host:         # SET the ssh host")
-            LOGGER.msg("   remote-port:         # SET the ssh port")
-            LOGGER.msg("   remote-incoming:     # SET ssh incoming directory")
-            LOGGER.msg("")
-        else:
-            raise PwpConfigError(f"Illegal argument '{arg}' for reset-ini")
-
     def run(self):
         do_exit = False  # exit is delayed until we have managed all --flag that generate exit
 
@@ -1273,10 +1119,6 @@ class PwpMain:
             licence.print()
             do_exit = True
 
-        if self.parser_config['reset-ini']:
-            self.reset_ini(self.parser_config['reset-ini'])
-            do_exit = True
-
         if self.parser_config['dump-config']:
             self.dump_config(self.parser_config['dump-config'], self.parser_config)
             do_exit = True
