@@ -436,31 +436,6 @@ La valeur de ce drapeau est le nom du nouveau fichier de configuration, il sera
     - exécuter  '--chdir tests\\results\\Usecase'
 """)  # noqa
 
-        self.add_item('reset-ini',
-                      help="Resets to default the ini file in the current directory and exits.",
-                      fr_help='Génère in fichier .ini par défaut dans le répertoire courant et sort',
-                      config="""
-- value = triage    Generates a configuration file *without* piwigo, used for triage only
-- value = default   Generates a configuration file with *all* values reset to their default
-- value = local     Generates a configuration file suitable for local access to piwigo directories
-- value = remote    Generates a configuration file suitable for remote (ssh) access to piwigo directories
-- value = None      Does nothing
-    
-Previous .ini file is renamed piwiPre.ini.bak, piwiPre.ini.bak is renamed piwiPre.ini.bak-1, etc """,
-                      fr_config="""
-- valeur = triage    Génère un fichier de configuration *sans* piwigo, uniquement pour renommer les fichiers
-- valeur = default   Génère un fichier de configuration avec *toutes* les valeurs remises à leur valeur par défaut
-- valeur = local     Génère un fichier de configuration pour un accès local aux répertoires de piwigo
-- valeur = remote    Génère un fichier de configuration pour un accès distant (ssh) aux répertoires de piwigo
-- valeur = None      Ne fait rien
-
-Le fichier .ini précédent est renommé piwi piwiPre.ini.bak, piwiPre.ini.bak est renommé piwiPre.ini.bak-1, etc...
-""",
-                      action='store',
-                      default=None,
-                      choices=['triage', 'default', 'local', 'remote', None],
-                      location='args')
-
         self.add_item('chdir',
                       help="Changes the default directory where piwiPre is run, is always executed BEFORE --ini-file",
                       fr_help="Change le répertoire d'où est exécuté piwiPré, toujours effectué AVANT --ini-file",
