@@ -190,7 +190,7 @@ class PwpPatcher:
                 self.rename(new_file, dst)
             else:
                 shutil.copy2(src, old_file)
-                shutil.copy2(new_file, dst)
+                self.rename(new_file, dst)
 
             print(f"msg     file '{dst}' patched")
 
@@ -204,7 +204,7 @@ class PwpPatcher:
         embedder.resize_and_convert(source, dst, 50, 29)
 
     def update_from_source(self, source, dst):
-        if os.path.getmtime(dst) > os.path.getmtime(source):
+        if os.path.getmtime(dst) > os.path.getmtime(source) and not self.args.autotest:
             print(f"msg     file '{dst}' is older than source '{source}': patch useless")  # pragma: no cover
             return                                                                              # pragma: no cover
 
@@ -234,7 +234,7 @@ class PwpPatcher:
 
         if os.path.isfile(old_file):
             os.remove(old_file)
-        shutil.copy2(source, old_file)
+        shutil.move(dst, old_file)
         self.rename(new_file, dst)
         print(f"msg     file '{dst}' patched")
 
@@ -339,8 +339,8 @@ class PwpPatcher:
                              {
                                  r".*exécutable Windows.*": f"{prologue_fr} `piwiPre-{self.spec}.exe " +
                                                             f"<{url_base}/{self.spec}/piwiPre-{self.spec}.exe>`_",
-                                 r".*lateur Wind.*": f"{prologue2_fr} `piwiPreInstaller-{self.spec}.exe " +  # noqa
-                                                     f"<{url_base}/{self.spec}/piwiPreInstaller-{self.spec}.exe>`_",
+                                 r".*lateur Wind.*": f"{prologue2_fr} `pwpInstaller-{self.spec}.exe " +  # noqa
+                                                     f"<{url_base}/{self.spec}/pwpInstaller-{self.spec}.exe>`_",
                                  r".*rateur Wind.*": f"{prologue3_fr} `pwpConfigurator-{self.spec}.exe " +  # noqa
                                                      f"<{url_base}/{self.spec}/pwpConfigurator-{self.spec}.exe>`_"
                              },
@@ -355,24 +355,23 @@ class PwpPatcher:
             print(f"msg     final tag '{self.spec}' at '{self.date}'")
             return
 
-        if self.args.sphinx:
+        if self.args.sphinx:      # pragma: no cover
             res = os.system("python -m sphinx source public/html -W -b html")
             print(f"msg     DONE: sphinx -> {res}")
 
-        if self.args.commit:
+        if self.args.commit:      # pragma: no cover
             commit = self.repo.git.commit('-a', '-m', f'set tag {self.spec}', '--date', self.date)
             print(f"msg     DONE: git commit '{str(commit)}' ")
 
-        if self.args.set_tag:
+        if self.args.set_tag:      # pragma: no cover
             self.repo.git.tag(self.spec)
             print(f"msg     DONE: git tag '{self.spec}'")
 
-        if self.args.push and self.origin:
-            # res = self.repo.git.push("--set-upstream", self.origin, self.repo.head.ref)
+        if self.args.push and self.origin:      # pragma: no cover
             res = self.repo.git.push('origin', self.spec)
             print(f"msg     DONE: git push {res}")
 
-        if self.args.exe:
+        if self.args.exe:      # pragma: no cover
             res = os.system("python -m PyInstaller -y piwiPre/__main__.py --onefile --name piwiPre")  # noqa
             print(f"msg     DONE: build exe piwiPre -> {res}")
             res = os.system("python -m PyInstaller -y piwiPre/pwpInstaller.py --onefile --name pwpInstaller")  # noqa
@@ -380,15 +379,15 @@ class PwpPatcher:
             res = os.system("python -m PyInstaller -y piwiPre/pwpConfigurator.py --onefile --name pwpConfigurator")  # noqa
             print(f"msg     DONE: build exe pwpConfigurator -> {res}")
 
-        if not self.args.pypi and not self.args.gitlab:
+        if self.args.pypi or self.args.gitlab: # pragma: no cover
+            pypi = "--Pypi" if self.args.pypi else ""
+            gitlab = "--GitLab" if self.args.gitlab else ""
+
+            res = os.system(f"python upload.py {pypi} {gitlab}")
+            print(f"msg     DONE: upload .py {pypi} {gitlab} -> {res}")
+        else:
             return
 
-        pypi = "--Pypi" if self.args.pypi else ""
-        gitlab = "--GitLab" if self.args.gitlab else ""
-
-        res = os.system(f"python upload.py {pypi} {gitlab}")
-        print(f"msg     DONE: upload .py {pypi} {gitlab} -> {res}")
-
 
 def patcher_main(arguments):
     arguments = arguments or []
